@@ -19,7 +19,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+#include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -31,22 +34,10 @@
 
 
 static void
-encrypt_sign_status_handler (GpgmeCtx ctx, GpgStatusCode code, char *args)
+encrypt_sign_status_handler (GpgmeCtx ctx, GpgmeStatusCode code, char *args)
 {
-  char *encrypt_info = 0;
-  int encrypt_info_len;
-
   _gpgme_encrypt_status_handler (ctx, code, args);
-
-  if (code == STATUS_EOF)
-    {
-      encrypt_info = gpgme_data_release_and_get_mem (ctx->op_info,
-						     &encrypt_info_len);
-      ctx->op_info = NULL;
-    }
   _gpgme_sign_status_handler (ctx, code, args);
-  if (code == STATUS_EOF && encrypt_info)
-    _gpgme_data_append (ctx->op_info, encrypt_info, encrypt_info_len);
 }
 
 
