@@ -52,18 +52,6 @@ struct engine_object_s
 };
 
 
-struct reap_s
-{
-  struct reap_s *next;
-  int pid;
-  time_t entered;
-  int term_send;
-};
-
-static struct reap_s *reap_list;
-DEFINE_STATIC_LOCK (reap_list_lock);
-
-
 /* Get the path of the engine for PROTOCOL.  */
 const char *
 _gpgme_engine_get_path (GpgmeProtocol proto)
@@ -262,7 +250,8 @@ _gpgme_engine_set_status_handler (EngineObject engine,
 
 GpgmeError
 _gpgme_engine_set_command_handler (EngineObject engine,
-				  GpgCommandHandler fnc, void *fnc_value)
+				  GpgCommandHandler fnc, void *fnc_value,
+				   GpgmeData linked_data)
 {
   if (!engine)
     return mk_error (Invalid_Value);
@@ -270,7 +259,8 @@ _gpgme_engine_set_command_handler (EngineObject engine,
   switch (engine->protocol)
     {
     case GPGME_PROTOCOL_OpenPGP:
-      return _gpgme_gpg_set_command_handler (engine->engine.gpg, fnc, fnc_value);
+      return _gpgme_gpg_set_command_handler (engine->engine.gpg,
+					     fnc, fnc_value, linked_data);
     case GPGME_PROTOCOL_CMS:
       /* FIXME */
       break;
@@ -340,6 +330,26 @@ _gpgme_engine_op_delete (EngineObject engine, GpgmeKey key, int allow_secret)
 }
 
 
+GpgmeError
+_gpgme_engine_op_edit (EngineObject engine, GpgmeKey key, GpgmeData out,
+		       GpgmeCtx ctx /* FIXME */)
+{
+  if (!engine)
+    return mk_error (Invalid_Value);
+
+  switch (engine->protocol)
+    {
+    case GPGME_PROTOCOL_OpenPGP:
+      return _gpgme_gpg_op_edit (engine->engine.gpg, key, out, ctx);
+    case GPGME_PROTOCOL_CMS:
+      /* FIXME */
+      return mk_error (Not_Implemented);
+    default:
+      break;
+    }
+  return 0;
+}
+
 GpgmeError
 _gpgme_engine_op_encrypt (EngineObject engine, GpgmeRecipients recp,
 			  GpgmeData plain, GpgmeData ciph, int use_armor)
@@ -587,84 +597,22 @@ _gpgme_engine_set_io_cbs (EngineObject engine,
     }
 }
 
-
 void
-_gpgme_engine_add_child_to_reap_list (void *buf, int buflen, pid_t pid)
+_gpgme_engine_io_event (EngineObject engine,
+			GpgmeEventIO type, void *type_data)
 {
-  /* Reuse the memory, so that we don't need to allocate another
-     memory block and to handle errors.  */
-  struct reap_s *child = buf;
+  if (!engine)
+    return;
 
-  assert (buflen >= sizeof *child);
-  memset (child, 0, sizeof *child);
-  child->pid = pid;
-  child->entered = time (NULL);
-  LOCK (reap_list_lock);
-  child->next = reap_list;
-  reap_list = child;
-  UNLOCK (reap_list_lock);
-}
-
-static void
-do_reaping (void)
-{
-  struct reap_s *r, *rlast;
-  static time_t last_check;
-  time_t cur_time = time (NULL);
-
-  /* A race does not matter here.  */
-  if (!last_check)
-    last_check = time (NULL);
-
-  if (last_check >= cur_time)
-    return;  /* We check only every second.  */
-
-  /* Fixme: it would be nice if to have a TRYLOCK here.  */
-  LOCK (reap_list_lock);
-  for (r = reap_list, rlast = NULL; r; rlast = r, r = r ? r->next : NULL)
+  switch (engine->protocol)
     {
-      int dummy1, dummy2;
-
-      if (_gpgme_io_waitpid (r->pid, 0, &dummy1, &dummy2))
-	{
-	  /* The process has terminated - remove it from the queue.  */
-	  void *p = r;
-	  if (!rlast)
-	    {
-	      reap_list = r->next;
-	      r = reap_list;
-            }
-	  else
-	    {
-	      rlast->next = r->next;
-	      r = rlast;
-            }
-	  xfree (p);
-        }
-      else if (!r->term_send)
-	{
-	  if (r->entered + 1 >= cur_time)
-	    {
-	      _gpgme_io_kill (r->pid, 0);
-	      r->term_send = 1;
-	      r->entered = cur_time;
-            }
-        }
-      else
-	{
-	  /* Give it 5 second before we are going to send the killer.  */
-	  if (r->entered + 5 >= cur_time)
-	    {
-	      _gpgme_io_kill (r->pid, 1);
-	      r->entered = cur_time; /* Just in case we have to repeat it.  */
-            }
-        }
+    case GPGME_PROTOCOL_OpenPGP:
+      _gpgme_gpg_io_event (engine->engine.gpg, type, type_data);
+      break;
+    case GPGME_PROTOCOL_CMS:
+      _gpgme_gpgsm_io_event (engine->engine.gpgsm, type, type_data);
+      break;
+    default:
+      break;
     }
-  UNLOCK (reap_list_lock);  
-}
-
-void
-_gpgme_engine_housecleaning (void)
-{
-  do_reaping ();
 }
