@@ -57,31 +57,6 @@ static struct key_cache_item_s *key_cache_unused_items;
    the cache.  */
 DEFINE_STATIC_LOCK (key_ref_lock);
 
-static int
-hextobyte (const byte *s)
-{
-  int c;
-
-  if (*s >= '0' && *s <= '9')
-    c = 16 * (*s - '0');
-  else if (*s >= 'A' && *s <= 'F')
-    c = 16 * (10 + *s - 'A');
-  else if (*s >= 'a' && *s <= 'f')
-    c = 16 * (10 + *s - 'a');
-  else
-    return -1;
-  s++;
-  if (*s >= '0' && *s <= '9')
-    c += *s - '0';
-  else if (*s >= 'A' && *s <= 'F')
-    c += 10 + *s - 'A';
-  else if (*s >= 'a' && *s <= 'f')
-    c += 10 + *s - 'a';
-  else
-    return -1;
-  return c;
-}
-
 static int
 hash_key (const char *fpr, unsigned int *rhash)
 {
@@ -90,16 +65,16 @@ hash_key (const char *fpr, unsigned int *rhash)
 
   if (!fpr)
     return -1;
-  if ((c = hextobyte (fpr)) == -1)
+  if ((c = _gpgme_hextobyte (fpr)) == -1)
     return -1;
   hash = c;
-  if ((c = hextobyte (fpr+2)) == -1)
+  if ((c = _gpgme_hextobyte (fpr+2)) == -1)
     return -1;
   hash |= c << 8;
-  if ((c = hextobyte (fpr+4)) == -1)
+  if ((c = _gpgme_hextobyte (fpr+4)) == -1)
     return -1;
   hash |= c << 16;
-  if ((c = hextobyte (fpr+6)) == -1)
+  if ((c = _gpgme_hextobyte (fpr+6)) == -1)
     return -1;
   hash |= c << 24;
 
@@ -392,6 +367,7 @@ _gpgme_key_add_secret_subkey (GpgmeKey key)
 void
 gpgme_key_release (GpgmeKey key)
 {
+  struct certsig_s *c, *c2;
   struct user_id_s *u, *u2;
   struct subkey_s *k, *k2;
 
@@ -417,6 +393,11 @@ gpgme_key_release (GpgmeKey key)
   for (u = key->uids; u; u = u2)
     {
       u2 = u->next;
+      for (c = u->certsigs; c; c = c2)
+        {
+          c2 = c->next;
+          xfree (c);
+        }
       xfree (u);
     }
   xfree (key->issuer_serial);
@@ -580,16 +561,10 @@ _gpgme_key_append_name (GpgmeKey key, const char *s)
   /* We can malloc a buffer of the same length, because the converted
      string will never be larger. Actually we allocate it twice the
      size, so that we are able to store the parsed stuff there too.  */
-  uid = xtrymalloc ( sizeof *uid + 2*strlen (s)+3);
+  uid = xtrymalloc (sizeof *uid + 2*strlen (s)+3);
   if (!uid)
     return mk_error (Out_Of_Core);
-  uid->revoked = 0;
-  uid->invalid = 0;
-  uid->validity = 0;
-  uid->name_part = NULL;
-  uid->email_part = NULL;
-  uid->comment_part = NULL;
-  uid->next = NULL;
+  memset (uid, 0, sizeof *uid);
   d = uid->name;
 
   while (*s)
@@ -630,7 +605,7 @@ _gpgme_key_append_name (GpgmeKey key, const char *s)
         }
       else if (s[1] == 'x' && isxdigit (s[2]) && isxdigit (s[3]))
 	{
-	  int val = hextobyte (&s[2]);
+	  int val = _gpgme_hextobyte (&s[2]);
 	  if (val == -1)
 	    {
 	      /* Should not happen.  */
@@ -783,6 +758,9 @@ gpgme_key_get_as_xml (GpgmeKey key)
   add_tag_and_uint (d, "len", key->keys.key_len);
   add_tag_and_time (d, "created", key->keys.timestamp);
   add_tag_and_time (d, "expire", key->keys.expires_at);
+  add_tag_and_string (d, "otrust",
+		      gpgme_key_get_string_attr (key, GPGME_ATTR_OTRUST,
+						 NULL, 0));
   if (key->issuer_serial)
     add_tag_and_string (d, "serial", key->issuer_serial);
   if (key->issuer_name)
@@ -894,6 +872,9 @@ gpgme_key_get_string_attr (GpgmeKey key, GpgmeAttr what,
       if (k) 
 	val = pkalgo_to_string (k->key_algo);
       break;
+    case GPGME_ATTR_TYPE:
+      val = key->x509? "X.509":"PGP";
+      break;
     case GPGME_ATTR_LEN:     
     case GPGME_ATTR_CREATED: 
     case GPGME_ATTR_EXPIRE:  
@@ -958,7 +939,6 @@ gpgme_key_get_string_attr (GpgmeKey key, GpgmeAttr what,
         }
       break;
     case GPGME_ATTR_LEVEL:
-    case GPGME_ATTR_TYPE:
     case GPGME_ATTR_KEY_REVOKED:
     case GPGME_ATTR_KEY_INVALID:
     case GPGME_ATTR_KEY_EXPIRED:
@@ -990,6 +970,7 @@ gpgme_key_get_string_attr (GpgmeKey key, GpgmeAttr what,
       val = key->chain_id;
       break;
     case GPGME_ATTR_SIG_STATUS:
+    case GPGME_ATTR_SIG_SUMMARY:
     case GPGME_ATTR_ERRTOK:
       /* Not of any use here.  */
       break;
@@ -1043,6 +1024,9 @@ gpgme_key_get_ulong_attr (GpgmeKey key, GpgmeAttr what,
       if (k) 
 	val = (unsigned long) k->key_len;
       break;
+    case GPGME_ATTR_TYPE:
+      val = key->x509? 1:0;
+      break;
     case GPGME_ATTR_CREATED: 
       for (k = &key->keys; k && idx; k = k->next, idx--)
 	;
@@ -1117,3 +1101,4 @@ gpgme_key_get_ulong_attr (GpgmeKey key, GpgmeAttr what,
     }
   return val;
 }
+
