@@ -24,92 +24,9 @@
 
 #include "types.h"
 
-
-typedef enum  {
-    STATUS_EOF ,
-    /* mkstatus starts here */
-    STATUS_ENTER	      , 
-    STATUS_LEAVE	      ,
-    STATUS_ABORT	      ,
-
-    STATUS_GOODSIG	      ,
-    STATUS_BADSIG	      ,
-    STATUS_ERRSIG	      ,
-
-
-    STATUS_BADARMOR           ,
-
-    STATUS_RSA_OR_IDEA        ,
-    STATUS_KEYEXPIRED         ,
-    STATUS_KEYREVOKED         ,
-
-    STATUS_TRUST_UNDEFINED    ,
-    STATUS_TRUST_NEVER        ,
-    STATUS_TRUST_MARGINAL     ,
-    STATUS_TRUST_FULLY        ,
-    STATUS_TRUST_ULTIMATE     ,
-
-    STATUS_SHM_INFO           ,
-    STATUS_SHM_GET	      ,
-    STATUS_SHM_GET_BOOL       ,
-    STATUS_SHM_GET_HIDDEN     ,
-
-    STATUS_NEED_PASSPHRASE    ,
-    STATUS_VALIDSIG           ,
-    STATUS_SIG_ID	      ,
-    STATUS_ENC_TO	      ,
-    STATUS_NODATA	      ,
-    STATUS_BAD_PASSPHRASE     ,
-    STATUS_NO_PUBKEY          ,
-    STATUS_NO_SECKEY          ,
-    STATUS_NEED_PASSPHRASE_SYM,
-    STATUS_DECRYPTION_FAILED  ,
-    STATUS_DECRYPTION_OKAY    ,
-    STATUS_MISSING_PASSPHRASE ,
-    STATUS_GOOD_PASSPHRASE    ,
-    STATUS_GOODMDC	      ,
-    STATUS_BADMDC	      ,
-    STATUS_ERRMDC	      ,
-    STATUS_IMPORTED 	      ,
-    STATUS_IMPORT_RES	      ,
-    STATUS_FILE_START	      ,
-    STATUS_FILE_DONE	      ,
-    STATUS_FILE_ERROR	      ,
-
-    STATUS_BEGIN_DECRYPTION   ,
-    STATUS_END_DECRYPTION     ,
-    STATUS_BEGIN_ENCRYPTION   ,
-    STATUS_END_ENCRYPTION     ,
-
-    STATUS_DELETE_PROBLEM     ,
-    STATUS_GET_BOOL 	      ,
-    STATUS_GET_LINE 	      ,
-    STATUS_GET_HIDDEN	      ,
-    STATUS_GOT_IT	      ,
-    STATUS_PROGRESS 	      ,
-    STATUS_SIG_CREATED	      ,
-    STATUS_SESSION_KEY        ,
-    STATUS_NOTATION_NAME      ,
-    STATUS_NOTATION_DATA      ,
-    STATUS_POLICY_URL         ,
-    STATUS_BEGIN_STREAM       ,
-    STATUS_END_STREAM         ,
-    STATUS_KEY_CREATED	      ,
-    STATUS_USERID_HINT	      ,
-    STATUS_UNEXPECTED         ,
-    STATUS_INV_RECP           ,
-    STATUS_NO_RECP            ,
-    STATUS_ALREADY_SIGNED     ,
-    STATUS_SIGEXPIRED         ,
-    STATUS_EXPSIG             ,
-    STATUS_EXPKEYSIG          ,
-    STATUS_TRUNCATED          ,
-    STATUS_ERROR              ,
-} GpgStatusCode;
-
-typedef void (*GpgStatusHandler)( GpgmeCtx, GpgStatusCode code, char *args ); 
+typedef void (*GpgStatusHandler)( GpgmeCtx, GpgmeStatusCode code, char *args ); 
 typedef void (*GpgColonLineHandler)( GpgmeCtx, char *line ); 
-typedef const char *(*GpgCommandHandler)(void*, GpgStatusCode code,
+typedef const char *(*GpgCommandHandler)(void*, GpgmeStatusCode code,
                                          const char *keyword);
 
 const char *_gpgme_gpg_get_version (void);
@@ -122,22 +39,25 @@ void       _gpgme_gpg_enable_pipemode ( GpgObject gpg );
 GpgmeError _gpgme_gpg_add_arg ( GpgObject gpg, const char *arg );
 GpgmeError _gpgme_gpg_add_data ( GpgObject gpg, GpgmeData data, int dup_to );
 GpgmeError _gpgme_gpg_add_pm_data ( GpgObject gpg, GpgmeData data, int what );
-void       _gpgme_gpg_set_status_handler ( GpgObject gpg,
-                                           GpgStatusHandler fnc,
-                                           void *fnc_value );
+void       _gpgme_gpg_set_status_handler (GpgObject gpg,
+					  GpgStatusHandler fnc,
+					  void *fnc_value);
 GpgmeError _gpgme_gpg_set_colon_line_handler ( GpgObject gpg,
                                                GpgColonLineHandler fnc,
                                                void *fnc_value );
 GpgmeError _gpgme_gpg_set_simple_line_handler ( GpgObject gpg,
                                                 GpgColonLineHandler fnc,
                                                 void *fnc_value );
-GpgmeError _gpgme_gpg_set_command_handler ( GpgObject gpg,
-                                            GpgCommandHandler fnc,
-                                            void *fnc_value );
+GpgmeError _gpgme_gpg_set_command_handler (GpgObject gpg,
+					   GpgCommandHandler fnc,
+					   void *fnc_value,
+					   GpgmeData linked_data);
 
 GpgmeError _gpgme_gpg_op_decrypt (GpgObject gpg, GpgmeData ciph,
 				  GpgmeData plain);
 GpgmeError _gpgme_gpg_op_delete (GpgObject gpg, GpgmeKey key, int allow_secret);
+GpgmeError _gpgme_gpg_op_edit (GpgObject gpg, GpgmeKey key, GpgmeData out,
+			       GpgmeCtx ctx /* FIXME */);
 GpgmeError _gpgme_gpg_op_encrypt (GpgObject gpg, GpgmeRecipients recp,
 				  GpgmeData plain, GpgmeData ciph,
 				  int use_armor);
@@ -162,5 +82,6 @@ GpgmeError _gpgme_gpg_op_trustlist (GpgObject gpg, const char *pattern);
 GpgmeError _gpgme_gpg_op_verify (GpgObject gpg, GpgmeData sig, GpgmeData text);
 GpgmeError _gpgme_gpg_spawn (GpgObject gpg, void *opaque);
 void _gpgme_gpg_set_io_cbs (GpgObject gpg, struct GpgmeIOCbs *io_cbs);
+void _gpgme_gpg_io_event (GpgObject gpg, GpgmeEventIO type, void *type_data);
 
 #endif /* RUNGPG_H */
