@@ -77,7 +77,7 @@ const char *_gpgme_get_gpgsm_path (void);
 #ifdef HAVE_CONFIG_H
 #if !HAVE_VASPRINTF
 #include <stdarg.h>
-int vasprintf (char **result, const char *format, va_list *args);
+int vasprintf (char **result, const char *format, va_list args);
 int asprintf (char **result, const char *format, ...);
 #endif
 
@@ -97,6 +97,8 @@ FILE *fopencookie (void *cookie, const char *opentype,
 #endif /*HAVE_CONFIG_H*/
 
 
-
+/*-- conversion.c --*/
+GpgmeError _gpgme_decode_c_string (const char *src, char **destp);
+int _gpgme_hextobyte (const byte *str);
 
 #endif /* UTIL_H */
